@@ -4,30 +4,36 @@ use warnings;
 use strict;
 use Carp qw( croak );
 
-our $VERSION = '0.0.1';
+our $VERSION = '0.0.2';
 
 my @tone_list = ('C', 'C#', 'D', 'D#', 'E', 'F', 'F#', 'G', 'G#', 'A', 'A#', 'B',
                  'C', 'C#', 'D', 'D#', 'E', 'F', 'F#', 'G', 'G#', 'A', 'A#', 'B');
 
 my $base_chord_list = {
     'base'     => '0,4,7',
-    'b5'       => '0,4,6',
+    '-5'       => '0,4,6',
     '6'        => '0,4,7,9',
     '6(9)'     => '0,4,7,9,14',         '69'       => '0,4,7,9,14',
     'M7'       => '0,4,7,11',
     'M7(9)'    => '0,4,7,11,14',        'M79'       => '0,4,7,11,14',
     'M9'       => '0,4,7,11,14',
+    'M11'      => '0,4,7,11,14,17',
+    'M13'      => '0,4,7,11,14,17,21',
     '7'        => '0,4,7,10',
     '7(b5)'    => '0,4,6,10',           '7b5'      => '0,4,6,10',
+    '7(-5)'    => '0,4,6,10',           '7-5'      => '0,4,6,10',
     '7(b9)'    => '0,4,7,10,13',        '7b9'      => '0,4,7,10,13',
-    'b9'       => '0,4,7,10,13',
-    'b9(#5)'   => '0,4,8,10,13',        'b9#5'     => '0,4,8,10,13',
-    #'7(b9,13)' => '',
-    '7(#9)'    => '0,4,7,10,15',        '7+9'      => '0,4,7,10,15',
-    '7(#11)'   => '0,4,7,10,15,18',     '7+11'     => '0,4,7,10,15,18',
-    '7(#13)'   => '0,4,10,21',          '7+13'     => '0,4,10,21',
+    '7(-9)'    => '0,4,7,10,13',        '7-9'      => '0,4,7,10,13',
+    '-9'       => '0,4,7,10,13',
+    '-9(#5)'   => '0,4,8,10,13',        '-9#5'     => '0,4,8,10,13',
+    '7(b9,13)' => '0,4,7,10,13,21',     '7(-9,13)' => '0,4,7,10,13,21',
+    '7(9,13)'  => '0,4,7,10,14,21',
+    '7(#9)'    => '0,4,7,10,15',        '7#9'      => '0,4,7,10,15',
+    '7(#11)'   => '0,4,7,10,15,18',     '7#11'     => '0,4,7,10,15,18',
+    '7(#13)'   => '0,4,10,21',          '7#13'     => '0,4,10,21',
     '9'        => '0,4,7,10,14',
     '9(b5)'    => '0,4,6,10,14',        '9b5'      => '0,4,6,10,14',
+    '9(-5)'    => '0,4,6,10,14',        '9-5'      => '0,4,6,10,14',
     '11'       => '0,4,7,10,14,17',
     '13'       => '0,4,7,10,14,17,21',
     'm'        => '0,3,7',
@@ -36,6 +42,7 @@ my $base_chord_list = {
     'mM7'      => '0,3,7,11',
     'm7'       => '0,3,7,10',
     'm7(b5)'   => '0,3,6,10',            'm7b5'    => '0,3,6,10',
+    'm7(-5)'   => '0,3,6,10',            'm7-5'    => '0,3,6,10',
     'm7(9)'    => '0,3,7,10,14',         'm79'     => '0,3,7,10,14',
     'm9'       => '0,3,7,10,14',
     'm7(9,11)' => '0,3,7,10,14,17',
